@@ -1,5 +1,6 @@
 from birdnetlib.watcher import DirectoryWatcher
 from birdnetlib.analyzer_lite import LiteAnalyzer
+from datetime import datetime
 from pprint import pprint
 
 
@@ -20,7 +21,12 @@ analyzer = LiteAnalyzer()
 print("Starting Watcher")
 directory = "."
 watcher = DirectoryWatcher(
-    directory, analyzer=analyzer, lon=-120.7463, lat=35.4244, week=18, min_conf=0.4
+    directory,
+    analyzers=[analyzer],
+    lon=-120.7463,
+    lat=35.4244,
+    date=datetime(year=2022, month=5, day=10),
+    min_conf=0.4,
 )
 
 watcher.on_analyze_complete = on_analyze_complete
